@@ -206,9 +206,9 @@ bdm.scp <- function( ... , dest = NULL){
 #'
 #' @param boost A running time accelerator factor. By default (\code{boost == 1}). See details.
 #'
-#' @param whiten Preprocessing of raw data. If \code{whiten = 4} (default value) raw data is preprocessed by computing the principal components (PCA) and whitening the rotated data. If \code{whiten = 3} only PCA is performed with NO whitening. If \code{whiten = 2} raw data is only centered and scaled. If \code{whiten = 1} raw data is only centered. If \code{whiten = 0} no preprocessing is performed at all.
+#' @param whiten Preprocessing of raw data. If \code{whiten = 4} (default value) raw data is transformed to principal components (PCA) and whitened afterwards. If \code{whiten = 3} only PCA is performed with NO whitening. If \code{whiten = 2} raw data is only centered and scaled. If \code{whiten = 1} raw data is only centered. If \code{whiten = 0} no preprocessing is performed at all.
 #'
-#' @param input.dim If \var{whiten} is TRUE, input.dim sets the number of principal components to be used as input dimensions. By default \code{input.dim = min(ncol(bdm$data), 30)}. If \var{whiten} is FALSE all data columns will be used as input dimensions (\code{input.dim = ncol(bdm$data)}).
+#' @param input.dim If raw data is given as (or is transformed to) principal components, \var{input.dim} sets the number of principal components to be used as input dimensions. Otherwise all data columns are used as input dimensions. By default \code{input.dim = ncol(bdm$data)}.
 #'
 #' @param ppx The value of perplexity to compute similarities (100 by default).
 #'
@@ -227,7 +227,9 @@ bdm.scp <- function( ... , dest = NULL){
 #' @details By default the algorithm is structured in \eqn{\sqrt{n}} epochs of \eqn{\sqrt{z}} iterations each, where \var{n} is the dataset size and \var{z} is the thread-size (\eqn{z=n*layers/threads}). The running time of the algorithm is then determined by \eqn{epochs*iters*t_i+ epochs*t_e} where \var{t_{i}} is the running time of a single iteration and \var{t_{e}} is the inter-epoch running time.
 #'
 #'The \var{boost} factor is meant to reduce the running time. With \eqn{boost > 1} the algorithm is structured in \eqn{n/boost} epochs with \eqn{z*boost} iterations each. This structure performs the same total number of iterations but arranged into a lower number of epochs, thus decreasing the total running time to \eqn{epochs*iters*t_i + 1/boost*epochs*t_e}. When the number of threads is high, the inter-epoch time can be high, in particular when using 'MPI' parallelization, thus, reducing the number of epochs can result in a significant reduction of the total running time. The counterpart is that increasing the number of iterations per epoch might result in a lack of convergence, thus the \var{boost} factor must be used with caution. To the most of our knowledge using values up to \eqn{boost=2.5} is generally safe.
-
+#'
+#' In case of extremely large datasets, we strongly recommend to initialize the \var{bdm} instance with already preprocessed data and use \code{whiten = 0}. Fast principal components approximations can be computed by means of \var{e.g.} \code{flashpcaR} or \code{scater} R packages.
+#'
 #' @examples
 #'
 #' # --- load example dataset
@@ -239,7 +241,7 @@ bdm.scp <- function( ... , dest = NULL){
 #' # --- plot the Cost function
 #' bdm.cost(exMap)
 #' # --- plot ptSNE output
-#' bdm.plot(exMap)
+#' bdm.ptsne.plot(exMap)
 
 bdm.ptsne <- function(bdm, threads = 3, type = 'SOCK', layers = 2, rounds = 1, boost = 2.0, whiten = 4, input.dim = NULL, ppx=100, itr=100, tol=1e-5, alpha=0.5, Y.init = NULL, info = 1)
 {
@@ -254,13 +256,13 @@ bdm.ptsne <- function(bdm, threads = 3, type = 'SOCK', layers = 2, rounds = 1, b
 	# +++ check if betas are already computed and can be reused
 	compute.Betas <- (is.null(bdm$Xbeta) || bdm$Xbeta$ppx != ppx || bdm$Xbeta$itr != itr || bdm$Xbeta$tol != tol || (!is.null(input.dim) && bdm$Xdata$input.dim != input.dim))
 	# +++ process/export raw data
-	Xdata <- Xdata.get(bdm$data, whiten, input.dim, bdm$is.distance)
+	Xdata <- Xdata.get(bdm$data, whiten = whiten, input.dim = input.dim, is.distance = bdm$is.distance)
 	if (is.null(Xdata$X)) return(bdm)
 	bdm$Xdata <- list(whiten = Xdata$whiten, input.dim = Xdata$input.dim)
 	Xdata.exp(cl, Xdata$X, bdm$is.distance)
 	# +++ compute/export similarities
 	if (compute.Betas){
-		bdm$Xbeta <- Xbeta.get(cl, Xdata$X, ppx, itr, tol, bdm$is.distance)
+		bdm$Xbeta <- Xbeta.get(cl, Xdata$X, ppx = ppx, itr = itr, tol = tol, is.distance = bdm$is.distance)
 	}
 	if (is.null(bdm$Xbeta)) return(bdm)
 	Xbeta.exp(cl, bdm$Xbeta$B)
@@ -313,7 +315,7 @@ bdm.ptsne <- function(bdm, threads = 3, type = 'SOCK', layers = 2, rounds = 1, b
 #' exMap <- bdm.pakde(exMap, threads = 4, ppx = 200, g = 200, g.exp = 3)
 #' }
 #' # --- plot paKDE output
-#' bdm.plot(exMap)
+#' bdm.pakde.plot(exMap)
 
 bdm.pakde <- function(bdm, layer = 1, threads = 2, type = 'SOCK', ppx = 100, itr = 100, tol = 1e-5, g = 200, g.exp = 3)
 {
@@ -355,7 +357,7 @@ bdm.pakde <- function(bdm, layer = 1, threads = 2, type = 'SOCK', ppx = 100, itr
 #' # --- perform WTT
 #' exMap <- bdm.wtt(exMap)
 #' # --- plot WTT output
-#' bdm.plot(exMap)
+#' bdm.wtt.plot(exMap)
 
 bdm.wtt <- function(bdm, layer = 1)
 {
@@ -390,9 +392,9 @@ bdm.wtt <- function(bdm, layer = 1)
 #' bdm.example()
 #' exMap.labels <- bdm.labels(exMap)
 
-bdm.labels <- function(bdm, layer = 1, merged = T){
-	# there is an internal version of this funcion (for simplicity)
-	# check optk.labels() in bdm_s2nr.R if any change is to be made here !!
+bdm.labels <- function(bdm, merged = T, layer = 1){
+	# At.!!! there is an internal version of this funcion (for simplicity)
+	# check merge.labels() in bdm_merge.R if any change is to be made here !!
 	if (!is.null(bdm$wtt[[layer]]))
 	{
 		C <- bdm$wtt[[layer]]$C
